@@ -121,11 +121,20 @@ class BaseDelegate(gobject.GObject):
         """Call show_all on the toplevel widget"""
         self.widget.show_all()
 
+    def hide(self):
+        """Call hide on the toplevel widget"""
+        self.widget.hide()
+
     def show_and_run(self):
         """Show the main widget and run the gtk loop"""
         self.show()
         gtk.main()
 
+    def hide_and_quit(self):
+        """Hide the widget and quit the main loop"""
+        self.hide()
+        gtk.main_quit()
+
     def _load_builder(self):
         builder = gtk.Builder()
         if self.builder_path:
@@ -153,7 +162,7 @@ class BaseDelegate(gobject.GObject):
         else: return
         self._toplevel = self.get_builder_toplevel(builder)
         for obj in builder.get_objects():
-            setattr(self, obj.get_name(), obj)
+            setattr(self, gtk.Buildable.get_name(obj), obj)
 
     def _connect_signals(self):
         for name in self._get_all_handlers():
